==> SD35B_0.02.1_src.tar.gz: Sd35b/decoder/CommandDriverG.cpp <==
/*
 * CommandDriverG.cpp
 *		- "ALICE SOFT System3.x" compatible scenario decoder SD35
 *
 * Copyright (C) 1999 Atsushi Mizuguchi  All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 * 
 * 
 */

#include "stdafx.h"
#include "CommandDriver.h"

#include "ScenarioDecoder.h"
#include "ScenarioParser.h"
#include "ExpressionDriver.h"
#include "GraphicDriver.h"

using namespace ALSD;
using namespace ALSD_CMDDRV;
using namespace ALSD_ALCG;
/**********************************************************************
	G command
**********************************************************************/
void CCommandDriver::_CommandG(void)
{
	switch( m_lpSD->GetParser()->GetC() ){
		case 0:
			CommandG0(); break;
		case 1:
			CommandG1(); break;
		case 'S':
			CommandGS(); break;
		case 'X':
			CommandGX(); break;
		default:
			throw EALSD_Msg( "error: G? unknown command\n" );
			break;
	}
}

/**********************************************************************
	nCJ[pbf[h
**********************************************************************/
void CCommandDriver::CommandG0( void )
{
	int num = m_lpED->GetExpValue() - 1;

	if( m_GPC & 0x00000001 )m_lpSD->GetGrpDriver()->LoadCG( num, -1 );

	TRACE( "command:G0( %d ) \n", num );
}

/**********************************************************************
	XvCgbf[h
**********************************************************************/
void CCommandDriver::CommandG1( void )
{
	long num = m_lpED->GetExpValue() - 1;
	long spc = m_lpED->GetExpValue();

	if( m_GPC & 0x00000001 )m_lpSD->GetGrpDriver()->LoadCG( num, spc );
	TRACE( "command:G1( %d ) \n", num );
}
/**********************************************************************
	bfWTCY擾
**********************************************************************/
void CCommandDriver::CommandGS( void )
{
	long num = m_lpED->GetExpValue() - 1;
	long*var = m_lpED->GetVariable();

	stCGSize size;
	m_lpGD->GetCGSizeInfo( num, &size );

	var[0] = size.x;
	var[1] = size.y;
	var[2] = size.Width;
	var[3] = size.Height;

	TRACE( "command:GS( %d ) \n", num );
}
/**********************************************************************
	ewbf[h
**********************************************************************/
void CCommandDriver::CommandGX( void )
{
	long cg = m_lpED->GetExpValue() - 1;
	long sh = m_lpED->GetExpValue() - 1;

	m_lpSD->GetGrpDriver()->LoadCGX( cg, sh );

	TRACE( "command:GX( %d, %d ) \n", cg, sh );
}

==> SD35B_0.02.2_src.tar.gz: Sd35b/decoder/CommandDriverG.cpp <==
/*
 * CommandDriverG.cpp
 *		- "ALICE SOFT System3.x" compatible scenario decoder SD35
 *
 * Copyright (C) 1999 Atsushi Mizuguchi  All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 * 
 * 
 */

#include "stdafx.h"
#include "CommandDriver.h"

#include "ScenarioDecoder.h"
#include "ScenarioParser.h"
#include "ExpressionDriver.h"
#include "GraphicDriver.h"

using namespace ALSD;
using namespace ALSD_CMDDRV;
using namespace ALSD_ALCG;
/**********************************************************************
	G command
**********************************************************************/
void CCommandDriver::_CommandG(void)
{
	switch( m_lpSD->GetParser()->GetC() ){
		case 0:
			CommandG0(); break;
		case 1:
			CommandG1(); break;
		case 'S':
			CommandGS(); break;
		case 'X':
			CommandGX(); break;
		default:
			throw EALSD_Msg( "error: G? unknown command\n" );
			break;
	}
}

/**********************************************************************
	nCJ[pbf[h
**********************************************************************/
void CCommandDriver::CommandG0( void )
{
	int num = m_lpED->GetExpValue() - 1;

	m_lpSD->GetGrpDriver()->LoadCG( num, -1 );

	TRACE( "command:G0( %d ) \n", num );
}

/**********************************************************************
	XvCgbf[h
**********************************************************************/
void CCommandDriver::CommandG1( void )
{
	long num = m_lpED->GetExpValue() - 1;
	long spc = m_lpED->GetExpValue();

	m_lpSD->GetGrpDriver()->LoadCG( num, spc );
	TRACE( "command:G1( %d ) \n", num );
}
/**********************************************************************
	bfWTCY擾
**********************************************************************/
void CCommandDriver::CommandGS( void )
{
	long num = m_lpED->GetExpValue() - 1;
	long*var = m_lpED->GetVariable();

	stCGSize size;
	m_lpGD->GetCGSizeInfo( num, &size );

	var[0] = size.x;
	var[1] = size.y;
	var[2] = size.Width;
	var[3] = size.Height;

	TRACE( "command:GS( %d ) \n", num );
}
/**********************************************************************
	ewbf[h
**********************************************************************/
void CCommandDriver::CommandGX( void )
{
	long cg = m_lpED->GetExpValue() - 1;
	long sh = m_lpED->GetExpValue() - 1;

	m_lpSD->GetGrpDriver()->LoadCGX( cg, sh );

	TRACE( "command:GX( %d, %d ) \n", cg, sh );
}
